<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
    <template slot="title">
      <i
        class="action-jeecg actionsite2"
        style="font-size: 18px;"
      />
      仓库信息
    </template>
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <!-- 搜索区域 -->
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="8"
            :sm="8"
          >
            <a-form-item label="仓库编号">
              <j-input
                placeholder="请输入仓库编号查询"
                v-model="queryParam.code"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="8"
            :sm="8"
          >
            <a-form-item label="仓库名称">
              <j-input
                placeholder="请输入仓库名称查询"
                v-model="queryParam.name"
              ></j-input>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div
      class="table-operator"
      style="margin-top: 5px"
    >
      <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        @click="searchReset"
        icon="reload"
      >重置</a-button>
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
      <a-button
        type="primary"
        icon="download"
        hidden
        @click="handleExportXls('???')"
      >导出</a-button>
      <a-dropdown
        hidden
        v-if="selectedRowKeys.length > 0"
      >
        <a-button style="margin-left: 8px">
          批量操作
          <a-icon type="down" />
        </a-button>
        <a-menu slot="overlay">
          <a-menu-item @click="batchDel">
            <a-icon type="delete" />删除
          </a-menu-item>
        </a-menu>
      </a-dropdown>
    </div>

    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="rowSelection"
      @change="handleTableChange"
      :scroll="{ x: 'calc(1200px + 50%)', y: 900 }"
      :customRow="clickThenSelect"
    >
      <span
        slot="action"
        slot-scope="text, record"
      >
        <a
          href="javascript:;"
          @click="handleEdit(record)"
        >编辑</a>
        <a-divider type="vertical" />
        <a-dropdown>
          <a class="ant-dropdown-link">
            更多
            <a-icon type="down" />
          </a>
          <a-menu slot="overlay">
            <a-menu-item>
              <a-popconfirm
                title="确定删除吗?"
                @confirm="() => handleDelete(record.id)"
              >
                <a>删除</a>
              </a-popconfirm>
            </a-menu-item>
          </a-menu>
        </a-dropdown>
      </span>
    </a-table>

    <a-tabs
      type="card"
      defaultActiveKey="1"
    >
      <a-tab-pane key="1">
        <span slot="tab">
          <a-badge v-if="showTabsFlag">库区库位&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
          <a-badge
            v-if="!showTabsFlag"
            :count="5"
            show-zero
            :number-style="{ backgroundColor: '#52c41a' }"
          >库区库位&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
        </span>
        <div
          class="table-operator"
          style="margin: 10px"
        >

          <warehouse-area-location-list ref="WarehouseAreaLocationList"></warehouse-area-location-list>
        </div>
      </a-tab-pane>

      <!-- <a-tab-pane
        key="2"
        forceRender
      >
        <span slot="tab">
          <a-badge v-if="showTabsFlag">管理对象&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
          <a-badge
            v-if="!showTabsFlag"
            :count="5"
            show-zero
            :number-style="{ backgroundColor: '#52c41a' }"
          >管理对象&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
        </span>
        <div
          class="table-operator"
          style="margin: 10px"
        >
          <manage-object-list ref="ManageObjectList"></manage-object-list>
        </div>
      </a-tab-pane>

      <a-tab-pane
        key="3"
        forceRender
      >
        <span slot="tab">
          <a-badge v-if="showTabsFlag">服务对象&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
          <a-badge
            v-if="!showTabsFlag"
            :count="5"
            show-zero
            :number-style="{ backgroundColor: '#52c41a' }"
          >服务对象&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
        </span>
        <div
          class="table-operator"
          style="margin: 10px"
        >
          <service-object-list ref="EquipmentFileList"></service-object-list>
        </div>
      </a-tab-pane> -->
    </a-tabs>
    <warehouse-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></warehouse-modal>
  </a-card>
</template>

<script>
import { requestPut, deleteAction, getFileAccessHttpUrl, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import WarehouseModal from './modules/warehouseNew/WarehouseModal.vue'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import Tooltip from 'ant-design-vue/es/tooltip'
import Vue from 'vue'

import WarehouseAreaLocationList from './modules/warehouseNew/WarehouseAreaLocationList'
import ManageObjectList from './modules/warehouseNew/ManageObjectList'
import ServiceObjectList from './modules/warehouseNew/ServiceObjectList.vue'

export default {
  name: 'WarehouseListNew.',
  mixins: [JeecgListMixin],
  components: {
    WarehouseModal,
    JInput,
    JEllipsis,
    WarehouseAreaLocationList,
    ManageObjectList,
    Tooltip,
    ServiceObjectList,
  },
  data() {
    return {
      showTabsFlag: true,
      disabled: true,
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '20'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      selectedRowKeys: [],
      selectionRows: [],
      //默认排序
      isorter: {
        column: 'code',
        order: 'desc',
      },

      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '仓库编码',
          align: "center",
          dataIndex: 'code',
        },
        {
          title: '仓库名称',
          align: "center",
          dataIndex: 'name',
        },
        {
          title: '仓库类型',
          align: "center",
          dataIndex: 'type_dictText',
        },
        {
          title: '是否废品库',
          align: "center",
          dataIndex: 'whetherWasteWarehouse_dictText',
        },
        {
          title: '库区库位管理',
          align: "center",
          dataIndex: 'locationManage_dictText',
        },
        {
          title: '服务对象类型',
          align: "center",
          dataIndex: 'serviceObject_dictText',
        },
        {
          title: '自动化',
          align: "center",
          dataIndex: 'whetherAutomationWarehouse_dictText',
        },
        {
          title: '备注',
          align: "center",
          dataIndex: 'remark',
        },
        {
          title: '操作',
          align: "center",
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action',
          },
          width: 200,
          fixed: 'right',
        },
      ],
      url: {
        list: "/base/warehouse/find",
        delete: "/base/warehouse/deleteWarehouseAreaLocation",
        active: "/eam/equipment/active",
        exportXlsUrl: '/eam/equipment/exportXls',
        importExcelUrl: 'base/site/importExcel',
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
    };
  },

  computed: {
    rowSelection() {
      return {
        type: 'checkbox',
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys;
          this.onSelectChange(selectedRowKeys, selectedRows);
        },
        getCheckboxProps(record) {
          return ({
            props: {
              // disabled: !(record.equipmentCategoryDtlList.length == 0),
            }
          })
        },
        selectedRowKeys: this.selectedRowKeys,
      };
    },
  },
  methods: {

    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(","), [record]);
          }
        }
      }
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      this.selectedRowKeys = selectedRowKeys;
      this.selectionRows = selectionRows;
      if (selectedRowKeys.length == 1) {
        this.$refs.WarehouseAreaLocationList.warehouseId = selectedRowKeys[0]
        // this.$refs.EquipmentFileList.warehouseId = selectedRowKeys[0]
        // this.$refs.ManageObjectList.warehouseId = selectedRowKeys[0]
      } else {
        this.$refs.WarehouseAreaLocationList.warehouseId = '-1'
        // this.$refs.ManageObjectList.warehouseId = '-1'
        // this.$refs.EquipmentFileList.warehouseId = '-1'
      }
    },

    //禁用状态样式
    tableRowClass(record, index) {
      if (record.status != "1") {
        return "frozenRowClass";
      }
      return "";
    },

    handleActive(id) {
      let that = this;
      requestPut(that.url.active, {}, { id: id }).then((res) => {
        if (res.success) {
          that.$message.success(res.message);
          that.loadData();
        } else {
          that.$message.warning(res.message);
        }
      });
    },
    handleAdd: function () {
      this.$refs.modalForm.add();
      this.$refs.modalForm.title = "新增";
      this.$refs.modalForm.disableSubmit = false;
    },
    handleDelete: function (id) {
      if (!this.url.delete) {
        this.$message.error("请设置url.delete属性!")
        return
      }
      var that = this;
      deleteAction(that.url.delete, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          that.$message.success(res.message);
          that.loadData();
          that.alterFlag = new Date();
          that.selectionRows = []
          that.selectedRowKeys = []
          that.$refs.WarehouseAreaLocationList.warehouseId = '-1'
        } else {
          that.$message.warning(res.message);
        }
      });
    },

    batchDel: function () {
      if (!this.url.deleteBatch) {
        this.$message.error("请设置url.deleteBatch属性!")
        return
      }
      if (this.selectedRowKeys.length <= 0) {
        this.$message.warning('请选择一条记录！');
        return;
      } else {
        var ids = "";
        for (var a = 0; a < this.selectedRowKeys.length; a++) {
          ids += this.selectedRowKeys[a] + ",";
        }
        var that = this;
        this.$confirm({
          title: "确认删除",
          content: "是否删除选中数据?",
          onOk: function () {
            that.loading = true;
            deleteAction(that.url.deleteBatch, { ids: ids }).then((res) => {
              if (res.success) {
                //重新计算分页问题
                that.reCalculatePage(that.selectedRowKeys.length)
                that.$message.success(res.message);
                that.loadData();
                that.onClearSelected();
                that.alterFlag = new Date();
              } else {
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.loading = false;
            });
          }
        });
      }
    },


    searchReset() {
      this.queryParam = {};
      this.selectedRowKeys = []
      this.selectionRows = []
      this.$refs.WarehouseAreaLocationList.warehouseId = '-1'
      this.loadData(1);

    },

    searchQuery() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.$refs.WarehouseAreaLocationList.warehouseId = '-1'
      // this.$refs.ManageObjectList.warehouseId = '-1'
      // this.$refs.EquipmentFileList.warehouseId = '-1'
      this.loadData(1);
    },

    modalFormOk() {
      // 新增/修改 成功时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()

      this.$refs.WarehouseAreaLocationList.warehouseId = '-1'
      // this.$refs.ManageObjectList.warehouseId = '-1'
      // this.$refs.EquipmentFileList.warehouseId = '-1'
    },
  },
  watch: {
    // alterFlag() {
    //   this.$bus.$emit('queryTreeData');
    // },
    selectionRows() {
      this.$bus.$emit('warehouseSelectionRows', this.selectionRows);
    },
  },
  created() {
    this.queryParam = {};
    this.selectedRowKeys = []
    this.selectionRows = []
    this.loadData(1);
  }


}
</script>
<style>
@import '~@assets/less/common.less';

.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
</style>